@@ -643,7 +643,7 @@ class ImagingReportRecordSet(PatientEventRecordSet):
 
 
 class ProtocolOverrideRecordSet(PatientRecordSet):
-    VALID_SYSTEMS: List[str] = ['cnvs']
+    VALID_SYSTEMS: List[str] = ['snomedct']
     PATIENT_FIELD = 'protocol_overrides'
     API_UPDATE_FIELD = 'protocolOverrides'
 
@@ -672,7 +672,12 @@ class ProtocolOverrideRecordSet(PatientRecordSet):
 
     @staticmethod
     def item_to_codes(item) -> List:
-        return [{
-            'code': item['protocolKey'],
-            'system': 'cnvs',
-        }]
+        snooze = item.get("snooze", {})
+        code = snooze.get("reasonCode")
+        system = snooze.get("reasonCodeSystem")
+        if code:
+            return [{
+                'code': code,
+                'system': system,
+            }]
+        return []
