@@ -38,7 +38,7 @@ from requests.auth import HTTPDigestAuth
 
 from . import events
 from .constants import CHANGE_TYPE
-from .metaclass import DeclarativeFieldsMetaclass
+from .metaclass import AttrDict, DeclarativeFieldsMetaclass
 from .patient import Patient
 from .recommendation import Recommendation, TaskRecommendation
 from .timeframe import Timeframe
@@ -372,6 +372,9 @@ class ClinicalQualityMeasure(Protocol):
 
         return self._results
 
+    def set_context(self, context: object = {}) -> None:
+        self.context = AttrDict(context)
+
     def recommendations(self) -> List[Recommendation]:
         return self.results().recommendations
 
@@ -402,8 +405,8 @@ class ClinicalQualityMeasure(Protocol):
         return 'between %s and %s' % (day_from.format('M/D/YY'), day_to.format('M/D/YY'))
 
     def screening_interval_context(self) -> str:
-        if hasattr(self, 'default_display_interval_in_days'):
-            abc = self.friendly_time_duration(self.default_display_interval_in_days)
+        if hasattr(self._meta, 'default_display_interval_in_days'):
+            abc = self.friendly_time_duration(self._meta.default_display_interval_in_days)
             if self.period_adjustment:
                 abc = self.friendly_time_duration(self.period_adjustment['cycleDays'])
             return f'Current screening interval {abc}.'
